<?php

class GRADIO_CMP_PlayerWidget extends BASE_CLASS_Widget
{
    private $uniqId;
    
    public function __construct( BASE_CLASS_WidgetParameter $paramObj, $template = null )
    {
        parent::__construct();
        
        $uniqId = 'gradio_' . str_replace('-', '', $paramObj->widgetDetails->uniqName);
        $this->assign('uniqId', $uniqId);
        
        $listenerVar = $uniqId . '_listener';
        $this->assign('listenerVar', $listenerVar);
        
        $swfUrl = OW::getPluginManager()->getPlugin('gradio')->getStaticUrl() . 'player.swf';
        $scriptUrl = OW::getPluginManager()->getPlugin('gradio')->getStaticUrl() . 'script.js';
        $themeUrl = OW::getPluginManager()->getPlugin('gradio')->getStaticUrl() . 'theme.css';
        
        $this->assign('swfUrl', $swfUrl);
        $this->assign('params', $paramObj->customParamList);
        
        $params = array(
            'url' => $paramObj->customParamList['radio_mount'],
            'website' => $paramObj->customParamList['radio_website'],
            'title' => $paramObj->customParamList['radio_title'],
            'autoplay' => (bool) $paramObj->customParamList['autoplay'],
            'volume' => empty($_COOKIE[$uniqId . '_volume']) ? 80 : intval($_COOKIE[$uniqId . '_volume']) 
        );
        
        $js = UTIL_JsGenerator::composeJsString(
	$listenerVar . ' = new GPlayerListener();' . "\n" .
        $uniqId . '_Handler = new GRadioPlayer({$uniqId}, {$params}, ' . $listenerVar . ');', array(
            'params' => $params,
            'uniqId' => $uniqId
        ));
        
	if ( OW::getRequest()->isAjax() )
	{
		OW::getDocument()->addOnloadScript($js);
	}
	else
	{
		OW::getDocument()->addScriptDeclaration($js);
	}

        OW::getDocument()->addScript($scriptUrl);
        OW::getDocument()->addStyleSheet($themeUrl);
    }
    
    public static function getSettingList()
    {
        $settingList = array();
        $settingList['radio_mount'] = array(
            'presentation' => self::PRESENTATION_TEXT,
            'label' => OW::getLanguage()->text('gradio', 'settings_mount_label'),
            'value' => ''
        );
        
        $settingList['radio_website'] = array(
            'presentation' => self::PRESENTATION_TEXT,
            'label' => OW::getLanguage()->text('gradio', 'settings_website_label'),
            'value' => ''
        );
        
        $settingList['radio_title'] = array(
            'presentation' => self::PRESENTATION_TEXT,
            'label' => OW::getLanguage()->text('gradio', 'settings_title_label'),
            'value' => ''
        );
        
        $settingList['autoplay'] = array(
            'presentation' => self::PRESENTATION_CHECKBOX,
            'label' => OW::getLanguage()->text('gradio', 'settings_autoplay_label'),
            'value' => 0
        );

        return $settingList;
    }
    
    public static function validateSettingList( $settingList )
    {
        if ( empty($settingList['radio_mount']) )
        {
            throw new WidgetSettingValidateException(OW::getLanguage()->text('gradio', 'required_field_message'), 'radio_mount');
        }
        
        if ( empty($settingList['radio_title']) )
        {
            throw new WidgetSettingValidateException(OW::getLanguage()->text('gradio', 'required_field_message'), 'radio_title');
        }
        
        if ( !empty($settingList['radio_website']) && !UTIL_Validator::isUrlValid($settingList['radio_website']) )
        {
            throw new WidgetSettingValidateException(OW::getLanguage()->text('gradio', 'radio_website_invalid_message'), 'radio_website');
        }
    }
    
    public static function getStandardSettingValueList()
    {
        return array(
            self::SETTING_TITLE => OW::getLanguage()->text('gradio', 'widget_title'),
            self::SETTING_SHOW_TITLE => false,
            self::SETTING_WRAP_IN_BOX => false,
            self::SETTING_ICON => self::ICON_MUSIC
        );
    }
}
